@@ -45,6 +45,7 @@ ResourceStatusValueType = Literal["PENDING"]
 SearchResourcesPaginatorName = Literal["search_resources"]
 ServiceName = Literal[
     "accessanalyzer",
+    "account",
     "acm",
     "acm-pca",
     "alexaforbusiness",
@@ -77,6 +78,7 @@ ServiceName = Literal[
     "chime-sdk-identity",
     "chime-sdk-messaging",
     "cloud9",
+    "cloudcontrol",
     "clouddirectory",
     "cloudformation",
     "cloudfront",
